@@ -23,9 +23,9 @@ class.  For those wishing to override the braille generators, however,
 one can create a new instance and replace/extend the braille
 generators as they see fit."""
 
-__id__        = "$Id: braillegenerator.py 4072 2008-08-01 20:47:02Z wwalker $"
-__version__   = "$Revision: 4072 $"
-__date__      = "$Date: 2008-08-01 16:47:02 -0400 (Fri, 01 Aug 2008) $"
+__id__        = "$Id: braillegenerator.py 4084 2008-08-04 21:19:09Z wwalker $"
+__version__   = "$Revision: 4084 $"
+__date__      = "$Date: 2008-08-04 17:19:09 -0400 (Mon, 04 Aug 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -1347,13 +1347,16 @@ class BrailleGenerator:
                         self._script.getRealActiveDescendant(obj))
 
                     if label == None or len(label) == 0:
-                        table = obj.parent.queryTable()
-                        index = self._script.getCellIndex(obj)
-                        n = table.getColumnAtIndex(index)
-                        accHeader = table.getColumnHeader(n)
-                        regions[0].append(braille.Region(" "))
-                        label = accHeader.name
-                        regions[0].append(braille.Region(label))
+                        try:
+                            table = obj.parent.queryTable()
+                            index = self._script.getCellIndex(obj)
+                            n = table.getColumnAtIndex(index)
+                            accHeader = table.getColumnHeader(n)
+                            regions[0].append(braille.Region(" "))
+                            label = accHeader.name
+                            regions[0].append(braille.Region(label))
+                        except:
+                            pass
 
                     break
 
