@@ -20,9 +20,9 @@
 """Uses speech prompts and a command line interface to set Orca
 user preferences."""
 
-__id__        = "$Id: orca_console_prefs.py 3882 2008-05-07 18:22:10Z richb $"
-__version__   = "$Revision: 3882 $"
-__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__id__        = "$Id: orca_console_prefs.py 4049 2008-07-19 21:01:34Z wwalker $"
+__version__   = "$Revision: 4049 $"
+__date__      = "$Date: 2008-07-19 17:01:34 -0400 (Sat, 19 Jul 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -387,18 +387,21 @@ def setupSpeech(prefsDict):
     # has a numeric keypad) and laptop (i.e., small and compact) keyboard
     # layouts for how they might control Orca.
     #
-    sayAndPrint(_("1. Desktop"))
+    sayAndPrint(_("1. Desktop"),
+                False, False, speechServerChoice, speechVoiceChoice)
 
     # Translators: we allow the user to choose between the desktop (i.e.,
     # has a numeric keypad) and laptop (i.e., small and compact) keyboard
     # layouts for how they might control Orca.
     #
-    sayAndPrint(_("2. Laptop"))
+    sayAndPrint(_("2. Laptop"),
+                False, False, speechServerChoice, speechVoiceChoice)
 
     try:
         # Translators: this is prompting for a numerical choice.
         #
-        choice = int(sayAndPrint(_("Enter choice: "), False, True))
+        choice = int(sayAndPrint(_("Enter choice: "),
+                     False, True, speechServerChoice, speechVoiceChoice))
     except:
         choice = -1
     if choice == 2:
