@@ -28,11 +28,11 @@ __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "2.23.90"
+version     = "2.23.91"
 
 # "--prefix" parameter used when configuring the build.
 #
-prefix      = "/home/wwalker/orca-devel"
+prefix      = "/usr"
 
 # The package name (should be "orca").
 #
